@@ -10,10 +10,10 @@ our @EXPORT_OK = qw( choose_videos set_sort_videolist );
 
 use Encode qw( decode );
 
-use Encode::Locale         qw();
-use List::MoreUtils        qw( any none );
-use Term::Choose           qw( choose );
-use Term::ReadLine::Simple qw();
+use Encode::Locale  qw();
+use List::MoreUtils qw( any none );
+use Term::Choose    qw( choose );
+use Term::Form      qw();
 
 use App::YTDL::Helper qw( check_mapping_stdout );
 
@@ -149,7 +149,7 @@ sub choose_videos {
                     delete $info->{$ex}{$video_id};
                 }
             }
-            my $trs = Term::ReadLine::Simple->new();
+            my $trs = Term::Form->new();
             $regexp = $trs->readline( "Regexp: " );
             next FILTER;
         }
