@@ -110,8 +110,7 @@ sub _parse_yt_list_html {
                     die "2 \$entry->{video_id} not defined!";
                 }
                 $entry->{title} = $el_id_and_title->attr( 'title' );
-
-                my $el_duration = $_->at(  'span[class*="video-time"] > span[title]' );
+                my $el_duration = $_->at(  'span[class*="video-time"] > span' );
                 if ( $el_duration ) {
                     my $duration = $el_duration->text;
                     if ( $duration && $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
