@@ -52,7 +52,7 @@ sub set_preferred_qualities {
             return;
         }
         $idx_choice -= @pre;
-        @pre = ( undef );
+        @pre = ( undef, 'RESET' );
         my $prompt = "Set preferred qualities ($ex):\n$choices[$idx_choice]";
         # Choose
         my @idx = choose(
@@ -62,6 +62,10 @@ sub set_preferred_qualities {
         if ( ! $idx[0] ) {
             next CHOICE;
         }
+        elsif ( $idx[0] == 1 ) {
+            $pref_qual->{$ex}[$idx_choice] = [];
+            next CHOICE;
+        }
         else {
             my @fmt_res_idx = map { $_ - @pre } @idx;
             my $fmt_list = [ @format_ids[@fmt_res_idx] ];
